function outstructure=peak_nii_inputs(instructure,hdrname,outputargs)
% Checks whether inputs are valid or not.
%   
%   ppi_nii_inputs.v2 last modified by Donald G. McLaren, PhD
%   (mclaren@nmr.mgh.harvard.edu)
%   GRECC, Bedford VAMC
%   Department of Neurology, Massachusetts General Hospital and Havard
%   Medical School
%% Format input instructure
while numel(fields(instructure))==1
    F=fieldnames(instructure);
    instructure=instructure.(F{1}); %Ignore coding error flag.
end

%% outfile
try
    outstructure.out=instructure.out;
    if isempty(outstructure.out)
        vardoesnotexist; % triggers catch statement
    end
catch
    [path,file]=fileparts(hdrname);
    outstructure.out=[path filesep file '_peaks_' date];
end

%% sign of data
try
    outstructure.sign=instructure.sign;
    if ~strcmpi(outstructure.sign,'pos') && ~strcmpi(outstructure.sign,'neg')
        vardoesnotexist; % triggers catch statement
    end
catch
    outstructure.sign='pos';
    disp('Using default option of positives for sign')
end

%% threshold
try
    outstructure.thresh=instructure.thresh;
    if ~isnumeric(outstructure.thresh)
        vardoesnotexist; % triggers catch statement
    end
    if outstructure.thresh<0
        if strcmpi(outstructure.type,'neg')
            outstructure.thresh=outstructure.thresh*-1;
        else
            vardoesnotexist; % triggers catch statement
        end
    end
catch
    outstructure.thresh=0;
    disp('Using default option of 0 for threshold')
end

%% statistic type (F or T)
try 
    outstructure.type=instructure.type;
    if ~strcmpi(outstructure.type,'T') && ~strcmpi(outstructure.type,'F') && ~strcmpi(outstructure.type,'none') && ~strcmpi(outstructure.type,'Z')
        vardoesnotexist; % triggers catch statement
    end
catch
    if outstructure.thresh<1 && outstructure.thresh>0
        error(['Statistic must defined using: ' instructure.type])
    else
        outstructure.type='none';
    end
end

%% voxel limit
try
    outstructure.voxlimit=instructure.voxlimit;
    if ~isnumeric(outstructure.voxlimit) || outstructure.voxlimit<0
        vardoesnotexist; % triggers catch statement
    end
catch
    outstructure.voxlimit=1;
    disp('Using default option of 1000 for voxel limit')
end

%% separation distance for peaks
try
    outstructure.separation=instructure.separation;
    if ~isnumeric(outstructure.separation) || outstructure.separation<0
        vardoesnotexist; % triggers catch statement
    end
catch
    outstructure.voxlimit=8;
    disp('Using default option of 8mm for separate peaks')
end

%% Output peaks or collapse peaks within a cluster (0 collapse peaks closer
% than separation distance, 1 remove peaks closer than separation distance
% to mirror SPM)
try
    outstructure.SPM=instructure.SPM;
    if ~isnumeric(outstructure.SPM) || (outstructure.SPM~=0 && outstructure.SPM~=1)
        vardoesnotexist; % triggers catch statement
    end
catch
    outstructure.SPM=0;
    disp('Using default option of collapsing peaks, this is not similar to SPM')
end
%% Connectivity radius
try
    outstructure.conn=instructure.conn;
    if ~isnumeric(outstructure.conn) || (outstructure.conn~=6 && outstructure.conn~=18 && outstructure.conn~=26)
        vardoesnotexist; % triggers catch statement
    end
catch
    outstructure.conn=18;
    disp('Using default option of face connected voxels, 18-voxel neighborhood')
end
%% Cluster extent threshold
try
    outstructure.cluster=instructure.cluster;
    if ~isnumeric(outstructure.cluster) || outstructure.cluster<0
        vardoesnotexist; % triggers catch statement
    end
catch
    outstructure.cluster=0;
    disp('Using default option of 0 voxels for cluster extent. This is BAD!!!!')
end
%% mask file
try
    outstructure.mask=instructure.mask;
    if ~isempty(outstructure.mask) && ~exist(outstructure.mask,'file')
        vardoesnotexist; % triggers catch statement
    end
catch
    outstructure.mask={};
    disp('Using default option of no mask')
end

%% degrees of freedom numerator
try
    outstructure.df1=instructure.df1;
    if ~isnumeric(outstructure.df1) || outstructure.df1<1
        vardoesnotexist; % triggers catch statement
    end
catch
    if (strcmpi(outstructure.type,'T') || strcmpi(outstructure.type,'F')) && (outstructure.thresh>0 && outstructure.thresh<1)
        error('degrees of freedom numerator must be defined using df1 field; can be gotten from SPM')
    else
    outstructure.df1=[];
    end
end

%% degrees of freedom denominator
try
    outstructure.df2=instructure.df2;
    if ~isnumeric(outstructure.df2) || outstructure.df2<1
        vardoesnotexist; % triggers catch statement
    end
catch
    if (strcmpi(outstructure.type,'F')) && (outstructure.thresh>0 && outstructure.thresh<1)
        error('degrees of freedom numerator must be defined using df2 field; can be gotten from SPM')
    else
    outstructure.df2=[];
    end
end

%% Make threshold a non-decimal
if (strcmpi(outstructure.type,'T') || strcmpi(outstructure.type,'F') || strcmpi(outstructure.type,'Z')) && (outstructure.thresh>0 && outstructure.thresh<1)
    if strcmpi(outstructure.type,'T')
        outstructure.thresh = spm_invTcdf(1-outstructure.thresh,outstructure.df1);
    elseif strcmpi(outstructure.type,'F')
        outstructure.thresh = spm_invFcdf(1-outstructure.thresh,outstructure.df1,outstructure.df2);
    else 
        outstructure.thresh=norminv(1-outstructure.thresh,0,1);
    end
end

%% Check for Peak Labels
try 
    outstructure.label.source=instructure.label;
    outstructure.label=roilabels(outstructure.label.source);
catch
    try 
        outstructure.label.source=instructure.label.source;
        outstructure.label=roilabels(outstructure.label.source);
    catch
        outstructure.label.source={};
        disp('Using default option of no labels.')
    end
end
try
    outstructure.label.nearest=instructure.nearest;
    if ~isnumeric(outstructure.label.nearest) || (outstructure.label.nearest~=0 && outstructure.label.nearest~=1)
        vardoesnotexist; % triggers catch statement
    end
catch
    outstructure.label.nearest=0;
    disp('Using default option of not using the nearest region label.')
end

% Labels needed?
if outputargs==2 && isempty(outstructure.label.source)
        error('Labels must be specified')
        % Program exits if it gets here.
end

%% Save structure
save([outstructure.out '_structure.mat'],'outstructure','-v7.3');
return

%% ROILABELS
function label=roilabels(source)

peak_nii_dir=fileparts(which('peak_nii.m'));
switch source
    case 'aal_MNI_V4'
        regionfile=[peak_nii_dir filesep 'aal_MNI_V4.img'];
        load([peak_nii_dir filesep 'aal_MNI_V4_List.mat']);
    case 'Nitschke_Lab'
        regionfile=[peak_nii_dir filesep 'ControlabilityMask.nii']; % Provided by Deb Kerr
        load([peak_nii_dir filesep 'ControlabilityMask_List.mat']);
    %case 'Custom'
    %    regionfile=['ROI image file'];
    %    load(['ROIlist mat-file']);
end

label.source=source;
label.rf.hdr=spm_vol(regionfile);
[label.rf.img,label.rf.XYZmm]=spm_read_vols(label.rf.hdr);
label.ROI=ROI;
label.ROInames={ROI.Nom_C}; %ROInames is taken from ROI, where ROI is structure
if ~isfield(ROI,'ID')
		 display('ERROR: ROI must be a structure with an ID field that is the ID of values in region file')
		 return
end
